@@ -13,7 +13,7 @@ class Deployment(object):
     Parcel will probably use this an instance of this class.
     """
 
-    virtual = "vp"
+    default_virtual = "vp"
     build_dir = '.parcel'
     
     # these are the full text versions of the scripts
@@ -29,7 +29,12 @@ class Deployment(object):
     preinst_lines = []
     postinst_lines = []
     
-    def __init__(self, app_name, build_deps=[], run_deps=[], path=".", base=None, arch=distro.Debian(), version=None):
+    def __init__(self, app_name, build_deps=None, run_deps=None, path=".", 
+		 base=None, arch=distro.Debian(), version=None, venv_dirname=default_virtual):
+        """Initialise the Deploy object. 
+        WARNING: This is not your usual contructor. Constructing this object makes an immediate fabric connection to the
+        remote host to fetch information and update. Be aware of this. This is probably bad.
+        """
 
         #: The architecture of the build host. This should be a :class:`Distro <Distro>` object. 
         self.arch = arch
@@ -53,18 +58,18 @@ class Deployment(object):
         self.app_name = app_name
 
         #: A list of packages that must be installed to run the resulting package.
-        self.run_deps = run_deps
+        self.run_deps = run_deps or []
 
         #: A list of packages that need to be installed to build the software.
-        self.build_deps = build_deps
+        self.build_deps = build_deps or []
         self.pkg_name = app_name.lower()
 
         #: The directory that will be used as the base level directory.
         self.path = os.path.realpath(path)
 
         #: Location of files during build on build host. Default is user's home directory.
-        #: If path is relative, it's relative to the remote user's home directory. If the path is absolute,
-        #: it's used as is.
+        #: If path is relative, it's relative to the remote user's home directory. 
+        #: If the path is absolute, it's used as is.
         self.base_path = os.path.join(remotehome,self.build_dir)
 
         self.pkg_name = app_name.lower()
@@ -76,18 +81,17 @@ class Deployment(object):
         # the build path
         self.build_path = os.path.join(self.root_path, self.app_path[1:])                # cut the first / off app_path
 
-        print "ROOT_PATH", self.root_path
-        print "BASE_PATH",self.base_path
-        print "APP PATH",self.app_path
-        print "BUILD PATH",self.build_path
+        # the name of the virtual environment dir
+        self.virtual = venv_dirname
 
         self._clean()
         
     def prepare_app(self, branch=None, requirements="requirements.txt"):
         """Creates the necessary directories on the build server, checks out the desired branch (None means current),
         creates a virtualenv and populates it with dependencies from requirements.txt. 
-        As a bonus it also fixes the shebangs (#!) of all scripts in the virtualenv to point the correct Python path
-        on the target system."""
+
+        :param requirements: The name of the requirements.txt file relative to the path setting used in the constructor.
+        """
         self._sync_app()
         self._add_venv(requirements)
             
@@ -119,19 +123,19 @@ class Deployment(object):
 
     def add_prerm(self, lines):
         """Add lines to the prerm file"""
-        self.prerm_lines.extend(lines)
+        self.prerm_lines = self.prerm_lines + lines
         
     def add_postrm(self, lines):
         """Add lines to the postrm file"""        
-        self.postrm_lines.extend(lines)
+        self.postrm_lines = self.postrm_lines + lines
         
     def add_preinst(self, lines):
         """Add lines to the preinst file"""        
-        self.preinst_lines.extend(lines)
+        self.preinst_lines = self.preinst_lines + lines
         
     def add_postinst(self, lines):
         """Add lines to the postinst file"""
-        self.postinst_lines.extend(lines)
+        self.postinst_lines = self.postinst_lines + lines
 
     def build_package(self, templates=True):
         """Takes the whole app including the virtualenv, packages it using fpm and downloads it to the local host.
@@ -214,11 +218,11 @@ class Deployment(object):
     def _add_venv(self,requirements="requirements.txt"):
         """Builds virtualenv on remote host and installs from requirements.txt.
         
-        :param requirements: The name of the requirements.txt file.
+        :param requirements: The name of the requirements.txt file relative to the path setting used in the constructor.
         """
         self.venv_path = os.path.join(self.build_path, self.virtual)
         run('virtualenv %s'%(self.venv_path))
-        if requirements and os.path.exists(requirements):
+        if requirements and os.path.exists(os.path.join(self.path, requirements)):
             run('PIP_DOWNLOAD_CACHE="%s" %s install -r %s'%(
                 self.arch.pip_download_cache,
 	            os.path.join(self.venv_path, 'bin/pip'),
